@@ -1,3 +1,4 @@
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2012 Nick Schermer <nick@xfce.org>
  *
@@ -410,7 +411,6 @@ gboolean
 thunar_device_can_eject (const ThunarDevice *device)
 {
   gboolean  can_eject = FALSE;
-  GMount   *volume_mount;
   GDrive   *drive;
 
   _thunar_return_val_if_fail (THUNAR_IS_DEVICE (device), FALSE);
@@ -423,21 +423,10 @@ thunar_device_can_eject (const ThunarDevice *device)
           can_eject = g_drive_can_eject (drive) || g_drive_can_stop (drive);
           g_object_unref (drive);
         }
-
-      if (!can_eject)
+      else
         {
           /* check if the volume can eject */
           can_eject = g_volume_can_eject (device->device);
-          if (!can_eject)
-            {
-              /* check if the mount can eject/unmount */
-              volume_mount = g_volume_get_mount (device->device);
-              if (volume_mount != NULL)
-                {
-                  can_eject = g_mount_can_eject (volume_mount) || g_mount_can_unmount (volume_mount);
-                  g_object_unref (volume_mount);
-                }
-            }
         }
     }
   else if (G_IS_MOUNT (device->device))
@@ -834,3 +823,33 @@ thunar_device_eject (ThunarDevice         *device,
       g_object_unref (G_OBJECT (mount));
     }
 }
+
+
+
+/**
+ * thunar_device_reload_file:
+ *
+ * Reload the related #ThunarFile of the #ThunarDevice
+ **/
+void
+thunar_device_reload_file (ThunarDevice *device)
+{
+  ThunarFile *file;
+  GFile      *mount_point;
+
+  _thunar_return_if_fail (THUNAR_IS_DEVICE (device));
+
+  mount_point = thunar_device_get_root (device);
+
+  if (mount_point != NULL)
+    {
+      /* try to determine the file for the mount point */
+      file = thunar_file_get (mount_point, NULL);
+      if (file != NULL)
+        {
+          thunar_file_reload (file);
+          g_object_unref (file);
+        }
+      g_object_unref (mount_point);
+    }
+}
